const { buildErrObject } = require('../../../middleware/utils')
const { listInitOptions, cleanPaginationID } = require('../../../middleware/db')

const follow = require('../../../models/Products')


/**
 * Gets items from database
 * @param {Object} req - request object
 * @param {Object} query - query object
 */
const followedClubsProducts = async(clubs = [], req = {}, query = {}) => {
    let options = await listInitOptions(req)
    options = { populate: { path: 'postedBy', select: 'name userName pictures' }, sort: { field: 'asc', createdAt: -1 }, limit: 5, page: req.query.page }
    query = {
        Archived: false,
        'userId': { $in: clubs }
    }
    return new Promise((resolve, reject) => {
        follow.paginate(query, options, (err, items) => {
            if (err) {
                return reject(buildErrObject(422, err.message))
            }
            resolve(cleanPaginationID(items))

        })
    })
}

module.exports = { followedClubsProducts }