const { registerUser, setUserInfo, returnRegisterToken, userNameExists } = require('./helpers')
const { amCreator } = require('../app/helpers/amCreator')
const { handleError } = require('../../middleware/utils')
const { createStripeCustomer } = require('../../paymentGetways/stripe/createCustomer')
const {
    emailExists,
    sendRegistrationEmailMessage,
} = require('../../middleware/emailer')

const { userNameExist } = require('../app/helpers/cheackUser')

/**
 * Register function called by route
 * @param {Object} req - request object
 * @param {Object} res - response object
 */
const register = async(req, res) => {
    console.log(req.body)
    try {
        // Gets locale from header 'Accept-Language'
        const locale = req.getLocale()
        const username = req.body.user.userName
        const userNameIsValid = usernameValid(username)
        if (userNameIsValid) {
            const doesEmailExists = await emailExists(req.body.user.email)
            const doesuserNameExists = await userNameExists(req.body.user.userName)
            delete req.body.user.role
            if (!doesuserNameExists && !doesEmailExists) {
                let item
                if (req.body.isCreator) {
                    req.body.user.role = 'creator'
                    item = await registerUser(req.body.user)
                    await amCreator(item._id, item.userName, true)
                } else {
                    item = await registerUser(req.body.user)
                    await amCreator(item._id, item.userName, false)
                }
                const newuser = await createStripeCustomer(item)
                const userInfo = await setUserInfo(newuser)
                const response = await returnRegisterToken(newuser, userInfo)
                sendRegistrationEmailMessage(locale, newuser)
                res.status(201).json(response)
            }

        }
    } catch (error) {
        handleError(res, error)
    }
}

module.exports = { register }
const usernameValid = async function(un = '') {
    const english = /^[A-Za-z0-9]*$/

    if (
        english.test(un) && un.length > 3 && un.length < 15) {
        return await userNameExist(un)
    }
}