const { getClub } = require('./helpers')
const { resolvePayment } = require('./helpers/resolvePayment.js')
const { handleError } = require('../../middleware/utils')
const { fillWallet } = require('../../middleware/payments')
const PackegeClaims = require('../../models/PackegeClaims')
const { createItem, createNotification, getItem, updateItem } = require('../../middleware/db')
const Packege = require('../../models/Packeges')
    /**
     * Get profile function called by route
     * @param {Object} req - request object
     * @param {Object} res - response object
     */
const claimPackage = async(req, res) => {
    try {
        const clubUsername = req.body.club
        const club = await getClub(clubUsername)
        if (club) {
            const paymentInfo = req.body.paymentInfo
            const user = {
                type: 'user',
                info: {
                    name: req.user.name,
                    username: req.user.userName,
                    image: req.user.pictures.profilePictureThump,
                    email: req.user.email,
                    id: req.user.id
                },
            }
            const item = await getItem(req.body.pId, Packege)
            const product = {
                type: 'package',
                info: item
            }
            const payment = await resolvePayment(paymentInfo, user, product, club, res)

            await fillWallet(payment.amount, club.userId)
            const payload = {
                Packege: item,
                user: {
                    name: req.user.name,
                    username: req.user.userName,
                    image: req.user.pictures.profilePictureThump,
                    email: req.user.email,
                    id: req.user.id
                },
                clubUserId: club.userId,
                paymentId: payment.id,
                info: req.body.info
            }
            await createNotification({
                sender: { name: req.user.name, image: req.user.pictures.profilePictureThump },
                receiverId: club.userId,
                content: `Just claimd your package ${item.title}, find more details in your club dashboard`
            }, )
            await createNotification({ receiverId: req.user.id, content: `you just claimed package ${item.title}, from @${club.userName}` }, )



            const r = await createItem(payload, PackegeClaims)
            res.status(200).json(r);
            if (item.options.limitedEdition.Active) {
                const op = item.options
                op.limitedEdition.limit - 1
                await updateItem(item.id, Packege, { options: op })
            }
        } else {
            handleError(res, { code: 404, message: 'errors.Club not found' })
        }
    } catch (error) {
        handleError(res, error)
    }
}
module.exports = { claimPackage }