const { getClub } = require('./helpers')
const { handleError } = require('../../middleware/utils')
const Products = require('../../models/Products')
const { getUserItems, checkQueryString } = require('../../middleware/db')

/**
 * Get profile function called by route
 * @param {Object} req - request object
 * @param {Object} res - response object
 */
const getClubProducts = async(req, res) => {
    try {
        const clubid = req.query.club
        const club = await getClub(clubid)
        if (club) {
            if (req.query.filter === 'all') {
                delete req.query.filter
                delete req.query.fields
            }
            const query = await checkQueryString(req.query)
            query.Archived = false
            res.status(200).json(await getUserItems(req, Products, query, club.userId));

        } else {
            handleError(res, { code: 404, message: 'errors.Club not found' })
        }
    } catch (error) {
        handleError(res, error)
    }
}

module.exports = { getClubProducts }