const { getClub, confirmSub, createFollow } = require('./helpers')
const { handleError } = require('../../middleware/utils')
const { fillWallet, gainMember } = require('../../middleware/payments')
const Subscription = require('../../models/Subscriptions')
const { createItem, createNotification, getItem } = require('../../middleware/db')
const SubscriptionChain = require('../../models/SubscriptionChain')
const PAyment = require('../../models/payments.js')
    /**
     * Get profile function called by route
     * @param {Object} req - request object
     * @param {Object} res - response object
     */
const joinClub = async(req, res) => {
    try {
        const clubUsername = req.body.club
        const club = await getClub(clubUsername)
        if (club) {
            const paymentInfo = req.body.paymentInfo
            const subid = req.body.pId
            const subscription = await getItem(subid, Subscription)
            const user = req.user
            const payment = await confirmSub(paymentInfo, res)
            const load = {
                paymentGetway: 'stripe',
                status: 'succeeded',
                amount: subscription.price,
                respcentUserId: club.userId,
                payingUser: {
                    type: 'user',
                    info: {
                        name: req.user.name,
                        username: req.user.userName,
                        image: req.user.pictures.profilePictureThump,
                        email: req.user.email,
                        id: req.user.id
                    },
                },
                userId: user.id,
                type: 'membership',
                paymentProviderId: payment.p.id,

            }
            const mp = await createItem(load, PAyment)

            await fillWallet(subscription.price, club.userId)
            const payload = {
                paymentId: mp.id,
                clubUserId: club.userId,
                club: { userName: club.userName },
                user: {
                    name: user.name,
                    username: user.userName,
                    image: user.pictures.profilePictureThump,
                    email: user.email,
                    id: user.id
                },
                subscription: subscription,
                subStripeId: payment.s.id,
                expireAt: payment.s.current_period_end,
                userId: user.id
            }
            await createFollow(req.user.id, club.id)
            await gainMember(club.userId)
            await createNotification({ receiverId: club.userId, content: `@${user.userName} Became a member in your club with level ${subscription.name}, find more details in your club dashboard` }, )
            await createNotification({ receiverId: user.id, content: `You Join club @${club.userName}, youe level is ${subscription.name}, Congratulations 🥳` }, )

            res.status(200).json(await createItem(payload, SubscriptionChain));



        } else {
            handleError(res, { code: 404, message: 'errors.Club not found' })
        }
    } catch (error) {
        handleError(res, error)
    }
}

module.exports = { joinClub }