const { getClub } = require('./helpers')
const { resolvePayment } = require('./helpers/resolvePayment.js')
const { handleError } = require('../../middleware/utils')
const Orders = require('../../models/orders')
const { createItem, createNotification, getItem } = require('../../middleware/db')
const Products = require('../../models/Products')
    /**
     * Get profile function called by route
     * @param {Object} req - request object
     * @param {Object} res - response object
     */
const makeOrder = async(req, res) => {
    try {
        const clubUsername = req.body.club
        const club = await getClub(clubUsername)
        if (club) {
            const paymentInfo = req.body.paymentInfo
            const user = { type: 'user', info: req.user }
            const item = await getItem(req.body.pId, Products)
            const product = {
                type: 'store',
                info: item
            }
            const payment = await resolvePayment(paymentInfo, user, product, club, res)

            const payload = {
                product: item,
                paymentId: payment.id,
                clubUserId: club.userId,
                userId: user.info.id,
                user: {
                    name: req.user.name,
                    username: req.user.userName,
                    image: req.user.pictures.profilePictureThump,
                    email: req.user.email,
                    phone: req.user.phoneNumber,
                    id: req.user.id
                },
                address: req.body.address,
                info: req.body.info,
                club: { userName: club.userName }
            }
            await createNotification({ receiverId: club.userId, content: `${user.info.name} made an order for the item ${item.name}, find more details in your club dashboard` }, )
            await createNotification({ receiverId: req.user.id, content: `you just made an order for the item ${item.name}, find more details in your orders page` }, )

            res.status(200).json(await createItem(payload, Orders));
            if (item.options.limitedEdition.Active) {

                await updateItem(item.id, Products, { options: { limitedEdition: { limit: item.options.limitedEdition.limit - 1, Active: true } } })
            }

        } else {
            handleError(res, { code: 404, message: 'errors.Club not found' })
        }
    } catch (error) {
        handleError(res, error)
    }
}
module.exports = { makeOrder }