const { getClub, resolvePayment } = require('./helpers')
const { handleError } = require('../../middleware/utils')
const { fillWallet } = require('../../middleware/payments')
const Support = require('../../models/support')
const { createItem, createNotification } = require('../../middleware/db')

/**
 * Get profile function called by route
 * @param {Object} req - request object
 * @param {Object} res - response object
 */
const suppourtUser = async(req, res) => {
    try {
        // const userid = await isIDGood(req.user._id)
        const clubUsername = req.body.club
        const club = await getClub(clubUsername)
        if (club) {
            const paymentInfo = req.body.paymentInfo
            const user = { type: req.body.user.type, info: req.user }
            const product = {
                type: 'support'
            }
            const payment = await resolvePayment(paymentInfo, user, product, club, res)
            const payload = {
                paymentId: payment.id,
                amount: payment.amount,
                clubUserId: club.userId,
                payingUser: {
                    name: user.info.name,
                    email: user.info.email,
                    image: user.info.pictures.profilePictureThump
                },
                info: {
                    message: req.body.data.message,
                    private: req.body.data.private
                }
            }
            await fillWallet(payment.amount, club.userId)
            await createNotification({
                sender: { name: req.user.name, image: req.user.pictures.profilePictureThump },
                receiverId: club.userId,
                content: `Supported with ${payment.amount}$, find more details in your club dashboard`
            }, )
            res.status(200).json(await createItem(payload, Support));
        } else {
            handleError(res, { code: 404, message: 'errors.Club not found' })
        }
    } catch (error) {
        handleError(res, error)
    }
}

module.exports = { suppourtUser }