const { handleError } = require('../../middleware/utils');
const Orders = require('../../models/orders');
const { getItems, checkQueryString, count } = require('../../middleware/db')


/**
 * Get all items function called by route
 * @param {Object} req - request object
 * @param {Object} res - response object
 */
const getClubOrders = async(req, res) => {
    try {
        const query = await checkQueryString(req.query)
        const orders = await getItems(req, Orders, query)
        const ordersCount = {
            new: await count({ clubUserId: req.user.id, Status: 'new' }, Orders),
            accepted: await count({ clubUserId: req.user.id, Status: 'accepted' }, Orders),
            rejected: await count({ clubUserId: req.user.id, Status: 'rejected' }, Orders),
            shipped: await count({ clubUserId: req.user.id, Status: 'shipped' }, Orders),
            all: await count({ clubUserId: req.user.id }, Orders)
        }
        orders.ordersCount = ordersCount

        res.status(200).json(orders)

    } catch (error) {
        handleError(res, error)
    }
}

module.exports = { getClubOrders }