const { buildErrObject } = require('../utils')
const { listInitOptions } = require('./listInitOptions')
const { cleanPaginationID } = require('./cleanPaginationID')
const Posts = require('../../models/posts.js')

/**
 * Gets items from database
 * @param {Object} req - request object
 * @param {Object} query - query object
 */
const getClubPosts = async(req = {}, query = {}, id = '', MembersOnly) => {
    let options = await listInitOptions(req)
    options = { populate: { path: 'postedBy', select: 'name userName pictures' }, sort: { field: 'asc', createdAt: -1 }, limit: 5 }
    query.userId = id
    if (MembersOnly !== 'all') {
        query.MembersOnly = MembersOnly
    }

    query.Archived = false

    return new Promise((resolve, reject) => {
        Posts.paginate(query, options, (err, items) => {
            if (err) {
                return reject(buildErrObject(422, err.message))
            }
            resolve(cleanPaginationID(items))
        })
    })
}

module.exports = { getClubPosts }