const { buildErrObject } = require('../utils')
const { listInitOptions } = require('./listInitOptions')
const { cleanPaginationID } = require('./cleanPaginationID')

/**
 * Gets items from database
 * @param {Object} req - request object
 * @param {Object} query - query object
 */
const getUserItems = async(req = {}, model = {}, query = {}, id = '') => {
    const options = await listInitOptions(req)
    query.userId = id

    return new Promise((resolve, reject) => {
        model.paginate(query, options, (err, items) => {
            if (err) {
                return reject(buildErrObject(422, err.message))
            }
            resolve(cleanPaginationID(items))
        })
    })
}

module.exports = { getUserItems }