const mongoose = require('mongoose')
const mongoosePaginate = require('mongoose-paginate-v2')
const mongooseAlgolia = require('mongoose-algolia')
const Schema = mongoose.Schema
const CitySchema = new mongoose.Schema({
    obType: { default: 'product', required: true, type: String },
    postedBy: { type: Schema.Types.ObjectId, required: true, ref: 'User' },
    storeId: {
        type: String,
        required: true
    },
    userId: {
        type: String,
        required: true
    },
    name: {
        type: String,
        required: true
    },
    price: {
        type: Number,
        required: true
    },
    description: {
        type: String,
        required: true
    },
    images: {
        type: Array,
        required: true
    },
    Discount: {
        type: Number,
        default: 0
    },
    isFeatuerd: {
        type: Boolean,
        default: false
    },
    NewProduct: {
        type: Boolean,
        default: true
    },
    Archived: {
        type: Boolean,
        default: false
    },
    categoryId: {
        type: String,
        required: true
    },
    attributes: {
        type: Array,
    },
    options: {
        type: Object,
        required: true
    },
    slug: {
        type: String,
        unique: true
    },
}, {
    versionKey: false,
    timestamps: true
})
CitySchema.pre('save', function(next) {
    this.slug = slugify(`${this.name} ${(Math.random() + 1).toString(36).substring(7)}`);
    next();
});
// function to slugify a name
function slugify(text) {
    return text.toString().toLowerCase()
        .replace(/\s+/g, '-') // Replace spaces with -
        .replace(/[^\w\-]+/g, '') // Remove all non-word chars
        .replace(/\-\-+/g, '-') // Replace multiple - with single -
        .replace(/^-+/, '') // Trim - from start of text
        .replace(/-+$/, ''); // Trim - from end of text
}
CitySchema.plugin(mongooseAlgolia, {
    appId: 'B4WLTPFLQ0',
    apiKey: 'e50b55681b994f62792f06595a83170c',
    indexName: 'products', //The name of the index in Algolia, you can also pass in a function
    selector: 'name description slug images', //You can decide which field that are getting synced to Algolia (same as selector in mongoose)
    populate: {
        path: 'description',
        select: 'name',
    },

    virtuals: {
        whatever: function(doc) {
            return { name: doc.name, description: doc.description, images: doc.images, slug: doc.slug };
        },
    },
    filter: function(doc) {
        return doc.Archived === false ? !doc.softdelete : doc.softdelete
    },
    // Default: false -> If true operations are logged out in your console
})
CitySchema.plugin(mongoosePaginate)

const Model = mongoose.model('Products', CitySchema)

Model.SyncToAlgolia() //Clears the Algolia index for this schema and synchronizes all documents to Algolia (based on the settings defined in your plugin settings)
Model.SetAlgoliaSettings({
    searchableAttributes: ['name', 'description'], //Sets the settings for this schema, see [Algolia's Index settings parameters](https://www.algolia.com/doc/api-client/javascript/settings#set-settings) for more info.
})
module.exports = Model