const mongoose = require('mongoose')
const mongoosePaginate = require('mongoose-paginate-v2')
const followChain = require('./followChain')
const CitySchema = new mongoose.Schema({
    userId: {
        type: String,
        required: true
    },
    likes: {
        type: Number,
        default: 0
    },
    bio: { type: String, default: '' },
    membersCount: {
        type: Number,
        default: 0
    },
    storeId: {
        type: String,
        required: true
    },
    userName: {
        type: String,
        required: true
    },
    links: {
        type: Array,
        default: []
    },
    info: {
        type: Object,
        default: {
            isNsfw: false,
            googleAnalytics: {
                Active: false,
                Code: ''
            },
            facebookPixel: {
                Active: false,
                Code: ''
            },

        }
    },
    isCreator: {
        type: Boolean,
        default: false
    },

    //TODO  isDisabled = false untile profile activated
    isDisabled: {
        type: Boolean,
        default: false
    },
}, {
    versionKey: false,
    timestamps: true
})

CitySchema.virtual('followCount', {
    ref: 'followChain',
    localField: 'userId',
    foreignField: 'clubId',
    count: true
});
CitySchema.pre('find', function() {
    this.populate('followCount');
});
CitySchema.post('find', async(docs) => {
    for (const doc of docs) {
        await doc.populate('followCount').execPopulate();
    }
});
// CitySchema.virtual('followCount').get(async function(doc) {
//         return await followChain.count({ clubId: doc.userId })
//     })
//     // CitySchema.set('toObject', { virtuals: true })
CitySchema.set('toJSON', { virtuals: true })
CitySchema.plugin(mongoosePaginate)
module.exports = mongoose.model('Club', CitySchema)