const mongoose = require('mongoose')
const mongoosePaginate = require('mongoose-paginate-v2')
const Schema = mongoose.Schema;

const CitySchema = new mongoose.Schema({
    payoutGetway: {
        type: Object,
        required: true
    },
    payedUser: {
        type: Schema.Types.ObjectId,
        ref: 'User'
    },
    walletId: {
        type: String,
        required: true
    },
    status: {
        type: String,
        enum: ['Accepted', 'Rejected', 'Pending', 'Done'],
        default: 'Pending'
    },
    amount: {
        type: Number,
        required: true
    },
}, {
    versionKey: false,
    timestamps: true
})
CitySchema.virtual('user', {
    ref: 'User',
    localField: 'payedUser', // Of post collection
    foreignField: '_id', // Of user collection
    justOne: true
})

CitySchema.set('toObject', { virtuals: true });
CitySchema.set('toJSON', { virtuals: true });

CitySchema.plugin(mongoosePaginate)

module.exports = mongoose.model('Payout', CitySchema)