const express = require('express')
const router = express.Router()
require('../../config/passport')
const passport = require('passport')
const requireAuth = passport.authenticate('jwt', {
    session: false
})
const trimRequest = require('trim-request')

const {
    register,
    verify,
    start,
    redirectAction,
    forgotPassword,
    resetPassword,
    getRefreshToken,
    login
} = require('../controllers/auth')

const {
    validateRegister,
    validateVerify,
    validateForgotPassword,
    validateResetPassword,
    validateLogin
} = require('../controllers/auth/validators')

/*
 * Auth routes
 */

/*
 * Register route
 */
router.post('/register', register)

/*
 * Verify route
 */
router.post('/verify', trimRequest.all, validateVerify, verify)

/*
 * Forgot password route
 */
router.post('/forgot', trimRequest.all, validateForgotPassword, forgotPassword)

/*
 * Reset password route
 */
router.post('/reset', trimRequest.all, validateResetPassword, resetPassword)

/*
 * Get new refresh token
 */
router.get(
    '/token',
    requireAuth,
    trimRequest.all,
    getRefreshToken
)

/*
 * Login route
 */
router.post('/login', trimRequest.all, validateLogin, login)
    /*
     * oauth login
     */

// router.get('/oauth/start/', start)
// router.post('/oauth/finish', finish)
// router.get('/oauth/redirect/', passport.authenticate('google'), redirectAction

// )
// router.get('/oauth/delete/')
module.exports = router