const express = require('express')
const router = express.Router()
require('../../config/passport')
const passport = require('passport')
const requireAuth = passport.authenticate('jwt', {
    session: false
})
const trimRequest = require('trim-request')

const { roleAuthorization } = require('../controllers/auth')

const {
    getProfile,
    updateProfile,
    changePassword,
    getmyPosts,
    getNotifications,
    getMyOrders,
    getMyClubs,
    getNotificationsStatus,
    cancelMembership,
} = require('../controllers/profile')

const {
    validateUpdateProfile,
    validateChangePassword
} = require('../controllers/profile/validators')

/*
 * Profile routes
 */

/*
 * Get profile route
 */
router.get(
    '/',
    requireAuth,
    roleAuthorization(['user', 'admin', 'creator']),
    trimRequest.all,
    getProfile
)

/*
 * Update profile route
 */
router.patch(
    '/',
    requireAuth,
    roleAuthorization(['user', 'admin', 'creator']),
    trimRequest.all,
    updateProfile
)

/*
 * Change password route†
 */
router.post(
        '/changePassword',
        requireAuth,
        roleAuthorization(['user', 'admin', 'creator']),
        trimRequest.all,
        validateChangePassword,
        changePassword
    )
    /*
     * Get my posts route
     */
router.get('/myposts', requireAuth, roleAuthorization(['creator']), getmyPosts)
    /*
     * Get noteifications status
     */
router.get('/notificationsFeed', requireAuth, getNotificationsStatus)

/*
 * Get my noteifications route
 */
router.get('/notifications', requireAuth, getNotifications)
    /*
     * Get my orders
     */
router.get('/orders', requireAuth, getMyOrders)
    /*
     * Get my clubs
     */
router.get('/clubs', requireAuth, getMyClubs)
    /*
     * Cancel membership
     */
router.post('/club', requireAuth, cancelMembership)
module.exports = router