const passport = require('passport')
const User = require('../app/models/user')
const auth = require('../app/middleware/auth')
const JwtStrategy = require('passport-jwt').Strategy
const { getUserByExternalId, socialSingup } = require('../app/controllers/auth/helpers')
    /**
     * Extracts token from: header, body or query
     * @param {Object} req - request object
     * @returns {string} token - decrypted token
     */
const jwtExtractor = (req) => {
    let token = null
    if (req.headers.authorization) {
        token = req.headers.authorization.replace('Bearer ', '').trim()
    } else if (req.body.token) {
        token = req.body.token.trim()
    } else if (req.query.token) {
        token = req.query.token.trim()
    }
    if (token) {
        // Decrypts token
        token = auth.decrypt(token)
    }
    return token
}
const config = require('./config.json')

/**
 * Options object for jwt middlware
 */
const jwtOptions = {
    jwtFromRequest: jwtExtractor,
    secretOrKey: config.appConfig.secret
}

/**
 * Login with JWT middleware
 */
const jwtLogin = new JwtStrategy(jwtOptions, (payload, done) => {
    User.findById(payload.data._id, (err, user) => {
        if (err) {
            return done(err, false)
        }
        return !user ? done(null, false) : done(null, user)
    })
})

passport.use(jwtLogin)

const passportFacebook = require('passport-facebook');



const passportConfig = {
    clientID: '1018259289128394',
    clientSecret: '8452ba935ca00b02de639e6fc356bed1',
    callbackURL: 'http://localhost:3000/oauth/redirect/?provider=facebook',
    profileFields: ['id', 'email', 'gender', 'link', 'locale', 'name', 'timezone', 'updated_time', 'verified'],

};

if (passportConfig.clientID) {
    passport.use(new passportFacebook.Strategy(passportConfig,
        function(req, accessToken, refreshToken, profile, done) {
            process.nextTick(async function() {
                console.log("Facebook authentication triggered")
                try {
                    // Check if the fb profile has an email associated. Sometimes FB profiles can be created by phone
                    // numbers in which case FB doesn't have an email - If email is not present, we fail the signup 
                    // with the proper error message
                    if (!profile._json.email) {
                        return done(null, false, { message: 'Facebook Account is not registered with email. Please sign in using other methods' })
                    }
                    let data = await utils.getOrCreateNewUserWithMedium(
                            accessToken,
                            profile.id,
                            profile._json.first_name,
                            profile._json.last_name,
                            profile._json.picture.data.url,
                            profile._json.email,
                            'facebook',
                            parseInt(req.query.state)) // An optional param you can pass to the request 
                    if (data.alreadyRegisteredError) {
                        // You can also support logging the user in and overriding the login medium
                        done(null, false, {
                            message: `Email is alredy registered with ${data.medium} account. Please login with email.`
                        });
                    } else {
                        done(null, { id: data.id, email: data.email, firstName: data.firstName, lastName: data.lastName });
                    }
                } catch (err) {
                    return done(null, null, { message: 'Unknown error' })
                }
            });
        }
    ));
}
const passportGoogle = require('passport-google-oauth');
const { json } = require('body-parser')
const passportGoogleConfig = {
    clientID: '900315915440-rqbi9epiu0b2m7hahli9co7skr3070n5.apps.googleusercontent.com',
    clientSecret: 'YlEHD_j2hkihkoSzgBI7e93E',
    callbackURL: 'http://localhost:3000/oauth/redirect/?provider=google',

};


passport.use(new passportGoogle.OAuth2Strategy(passportGoogleConfig,
    //     async function (request, accessToken, refreshToken, profile, done) {

    //     // See if this user already exists
    //     console.log("Google authentication triggered")
    //     console.log(request)
    //     const { isSingup, username } = JSON.parse(request.query)
    //     console.log('Creating new user  ' + isSingup + typeof isSingup)
    //     const user = await getUserByExternalId('google', profile.id)
    //     if (isSingup) {
    //         const s = await usernameValid(username)
    //         console.log(`singup start: ${username} s  ${s}`)
    //         if (s) {
    //             if (!profile._json.email) {
    //                 done(null, false, { message: 'Google Account is not registered with email. Please sign in using other methods' })
    //             }
    //             if (!user) {
    //                 const options = {
    //                     verified: true,
    //                     provider: 'google',
    //                     userName: username,
    //                     name: `${profile.name.givenName} ${profile.name.familyName}`,
    //                     firstName: profile.name.givenName,
    //                     lastName: profile.name.familyName,
    //                     email: profile.emails[0].value,
    //                     pictures: { profilePicture: profile._json.picture, profilePictureThump: profile._json.picture, cover: 'https://res.cloudinary.com/fanband/image/upload/v1644593174/136-1365453_no-copyright-background-images-brighton_shfbab.jpg' },
    //                     providerId: profile.id
    //                 }
    //                 console.log(options)
    //                 const newUser = socialSingup(options)
    //                 console.log('singup finished')
    //                 return done(null, newUser)
    //             }
    //         }

    //         // console.log('user', user)
    //     }
    //     return done(null, user);
    // }));
    function(req, accessToken, refreshToken, profile, done) {
        console.log("Google authentication triggered")
        process.nextTick(async function() {
            try {
                const { isSingup, username } = JSON.parse(req.query)
                console.log('Creating new user  ' + username + isSingup + typeof isSingup)

                // Check if the google profile has an email associated. Sometimes google profiles can be created by phone
                // numbers in which case google doesn't have an email - if email is not present, 
                // we fail the signup with the proper error message
                if (!profile._json.email) {
                    return done(null, false, { message: 'Google Account is not registered with email. Please sign in using other methods' })
                }
                const user = await getUserByExternalId('google', profile.id)
                if (user) {
                    return done(null, user)
                } else {
                    if (isSingup) {
                        const options = {
                            verified: true,
                            provider: 'google',
                            userName: username,
                            name: `${profile.name.givenName} ${profile.name.familyName}`,
                            firstName: profile.name.givenName,
                            lastName: profile.name.familyName,
                            email: profile.emails[0].value,
                            pictures: { profilePicture: profile._json.picture, profilePictureThump: profile._json.picture, cover: 'https://res.cloudinary.com/fanband/image/upload/v1644593174/136-1365453_no-copyright-background-images-brighton_shfbab.jpg' },
                            providerId: profile.id
                        }
                        console.log(options)
                        const newUser = await socialSingup(options)
                        console.log('singup finished')
                        return done(null, newUser)
                    }
                }

            } catch (err) {
                return done(null, null, { message: 'Unknown error' })
            }
        });
    }
));